"""
Droplet Contact Numbers and Probabilities (DCNumPro)

Determine droplet contact numbers and probabilities based on 
the median and the standard deviation of a droplet size distribution.

Source code of DCNumPro: https://git.rwth-aachen.de/avt-fvt/public/contact-numbers-and-probabilities/
DCNumPro uses a 3D cell-based Voronoi library based on voro++: https://github.com/wackywendell/tess

The source code of DCNumPro is licensed under the Eclipse Public License v2.0 (EPL 2.0).
Copyright (c) 2024 Fluid Process Engineering (AVT.FVT), RWTH Aachen University.
Written by Stepan Sibirtsev & Andrey Kirsanov

The coyprights and license terms are given in LICENSE.

In this script configurations for the DCNumPro_main.py script are set.
Script version date: 23.11.2024
"""  
# Perform on cluster? False = no, True = yes
# If cluster = True, no further configuration is required since the configuration is performed in the .JOB file
# Default: False
cluster = False
# Graphically display particles in 3D? False = no, True = yes
# Extremly time consuming at high paticle numbers.
# Default: False
display_particles = False
# Final test for overlaps after random loose packing simulation? False = no, True = yes
# Default: True
final_test = True
# Display detailed progress status of random loose packing simulation at each step? False = no, True = yes
# Useful for developers.
# If False, only overall percentage progress will be displayed.
# Default: False
display_detailed_progress = False
# Display solver warnings? False = no, True = yes
# Useful for developers.
# Default: False
display_solver_warnings = False
# Output Excel file.
# Default: Test
name_excel_file = 'Test'
# Number of initial particles.
# Default: 5000
n_particles_sim = 5000
# Number of classes.
# Default: 10
n_classes = 10
# Droplet size distribution type. 0 = log-normal, 1 = Gaussian
# Default: 0
dsd_type = 0
# Median of the droplet size distribution.
# Not the mean of log values in case of log-normal DSD!
# Default: 330
mu = 330
# Standard deviation of the droplet size distribution.
# Not the standard deviation of log values in case of log-normal DSD!
# Default: 130
sigma = 130
# Estimated packing hold-up after random loose packing simulation. 
# Defines the height-width-depth ratio of the simulation environment (cube).
# Default: 0.55
holdup_est = 0.55
# Random seed for the random loose packing simulation.
# Default: 5
seed = 5
# Number of CPU cores for multiprocessing. 0 = automated determination of available cores.
# Default: 0
n_cores = 6
# Hold-up steps at constant growth to calculate the grow factors for the growth simulation.
# Default: 0.025
holdup_delta_const = 0.2
# Hold-up steps at non-constant growth to calculate the grow factors for the growth simulation.
# Default: 0.2
holdup_delta_nonconst = 0.2
# Stepsize for the random loose packing simulation.
# Default: 1
stepsize = 1
""" Configuration ends here """

# Assign parameter to int and float
n_particles_sim = int(n_particles_sim)
n_classes = int(n_classes)
holdup_est = float(holdup_est)
seed = int(seed)
n_cores = int(n_cores)
holdup_delta_const = float(holdup_delta_const)
holdup_delta_nonconst = float(holdup_delta_nonconst)
stepsize = float(stepsize)
dsd_type = int(dsd_type)
mu = float(mu)
sigma = float(sigma)